OpenStax.Swift v0.3.0 OpenStax.Swift.API.Account View Source

This module is responsible for wrapping HTTP requests sent to Swift when it comes to account handling.

Link to this section Summary

Functions

Creates, updates, or deletes account metadata

Shows details for an account and lists containers, sorted by name, in the account

Link to this section Functions

Link to this function create(endpoint_id, metadata \\ nil) View Source

Creates, updates, or deletes account metadata.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#updateAccountMeta

Shows details for an account and lists containers, sorted by name, in the account.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#showAccountDetails