OpenStax.Swift v0.3.0 OpenStax.Swift.API.Container View Source

This module is responsible for wrapping HTTP OpenStax.Swift.Request.requests sent to Swift when it comes to container handling.

Link to this section Summary

Functions

Deletes an empty container

Shows container metadata, including the number of objects and the total bytes of all objects stored in the container

Shows details for a container and lists objects, sorted by name, in the container

Creates, updates, or deletes custom metadata for a container

Link to this section Functions

Link to this function create(endpoint_id, container, metadata \\ nil) View Source

Creates a container.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#createContainer

Link to this function delete(endpoint_id, container) View Source

Deletes an empty container.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#deleteContainer

Link to this function get_meta(endpoint_id, container) View Source

Shows container metadata, including the number of objects and the total bytes of all objects stored in the container.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#showContainerMeta

Link to this function read(endpoint_id, container) View Source

Shows details for a container and lists objects, sorted by name, in the container.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#showContainerDetails

Link to this function set_meta(endpoint_id, container, metadata \\ nil) View Source

Creates, updates, or deletes custom metadata for a container.

See http://developer.openstack.org/api-ref-objectstorage-v1.html#updateContainerMeta